@@ -1,7 +1,7 @@
 use indexmap::IndexMap;
 use serde::{Deserialize, Serialize};
 
-use crate::{Channel, Components, ExternalDocumentation, Info, Server, Tag};
+use crate::{Channel, Components, ExternalDocumentation, Info, ReferenceOr, Server, Tag};
 
 /// This is the root document object for the API specification.
 /// It combines resource listing and API declaration together into one document.
@@ -35,11 +35,11 @@ pub struct AsyncAPI {
     /// designed for `1.0.0`.
     pub asyncapi: String,
     /// Identifier of the
-    /// [application](https://www.asyncapi.com/docs/specifications/v2.1.0#definitionsApplication)
+    /// [application](https://www.asyncapi.com/docs/specifications/v2.3.0#definitionsApplication)
     /// the AsyncAPI document is defining.
     ///
     /// This field represents a unique universal identifier of the
-    /// [application](https://www.asyncapi.com/docs/specifications/v2.1.0#definitionsApplication)
+    /// [application](https://www.asyncapi.com/docs/specifications/v2.3.0#definitionsApplication)
     /// the AsyncAPI document is defining. It must conform to the URI format,
     /// according to [RFC3986](https://tools.ietf.org/html/rfc3986).
     ///
@@ -98,15 +98,16 @@ pub struct AsyncAPI {
     ///     protocolVersion: '1.0.0'
     /// ```
     #[serde(default, skip_serializing_if = "IndexMap::is_empty")]
-    pub servers: IndexMap<String, Server>,
+    pub servers: IndexMap<String, ReferenceOr<Server>>,
     /// Default content type to use when encoding/decoding a message's payload.
     /// A string representing the default content type to use when encoding/decoding a
     /// message's payload. The value MUST be a specific media type (e.g. `application/json`).
     /// This value MUST be used by schema parsers when the
-    /// [contentType](https://www.asyncapi.com/docs/specifications/v2.1.0#messageObjectContentType) property is omitted.
+    /// [contentType](https://www.asyncapi.com/docs/specifications/v2.3.0#messageObjectContentType)
+    /// property is omitted.
     ///
-    /// In case a message can't be encoded/decoded using this value, schema parsers MUST use
-    /// their default content type.
+    /// In case a message can't be encoded/decoded using this value, schema
+    /// parsers MUST use their default content type.
     ///
     /// # Examples
     /// ```json
@@ -130,8 +131,7 @@ pub struct AsyncAPI {
     /// Each item is a relative path to an individual channel. The field name MUST be in
     /// the form of a [RFC 6570 URI template](https://tools.ietf.org/html/rfc6570).
     /// Query parameters and fragments SHALL NOT be used, instead use
-    /// [bindings](https://www.asyncapi.com/docs/specifications/v2.1.0#channelBindingsObject)
-    /// to define them.
+    /// [bindings][crate::ChannelBinding] to define them.
     ///
     /// # Examples
     ///
@@ -162,7 +162,7 @@ pub struct AsyncAPI {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub external_docs: Option<ExternalDocumentation>,
     /// This object can be extended with
-    /// [Specification Extensions](https://www.asyncapi.com/docs/specifications/v2.1.0#specificationExtensions).
+    /// [Specification Extensions](https://www.asyncapi.com/docs/specifications/v2.3.0#specificationExtensions).
     #[serde(flatten)]
     pub extensions: IndexMap<String, serde_json::Value>,
 }
