@@ -3,7 +3,6 @@ mod channel;
 pub mod channel_binding;
 mod components;
 mod correlation_id;
-mod discriminator;
 mod example;
 mod external_documentation;
 mod info;
@@ -26,7 +25,6 @@ pub use channel::{Channel, Operation};
 pub use channel_binding::ChannelBinding;
 pub use components::Components;
 pub use correlation_id::CorrelationId;
-pub use discriminator::Discriminator;
 pub use example::Example;
 pub use external_documentation::ExternalDocumentation;
 pub use info::{Contact, Info, License};
@@ -43,9 +41,3 @@ pub use server::{SecurityRequirement, Server, ServerVariable};
 pub use server_binding::ServerBinding;
 pub use tag::Tag;
 pub use variant_or::{VariantOrUnknown, VariantOrUnknownOrEmpty};
-
-#[allow(clippy::trivially_copy_pass_by_ref)] // needs to match signature for use in serde attribute
-#[inline]
-pub(crate) const fn is_false(v: &bool) -> bool {
-    !(*v)
-}
